@@ -76,6 +76,7 @@ private slots :
 	void mountPointPath( QString ) ;
 	void cbStateChanged( int ) ;
 private :
+	void autoSetPassword( const QString& ) ;
 	void keyAndKeyFile( void ) ;
 	void tcryptGui( void ) ;
 	void openVolume( void ) ;
@@ -96,6 +97,7 @@ private :
 	QWidget * m_parent ;
 	QByteArray m_key ;
 	QStringList m_keyFiles ;
+	QString m_fsOptions ;
 	QString m_device ;
 	QString m_point ;
 	QString m_plainDmCryptProperty ;
